var DateParser ={
/**
* parse the input string as a date object.
* Format: MM/dd/yyyy hh:mm:ss
* if failure, null will be returned
**/
parseDate:function (input)
{
    var timeArray = input.split(" ");
    if(timeArray.length<2)return null;
    var subarray1 = timeArray[0].split("/");
    var subarray2 = timeArray[1].split(":");
    if(subarray1.length<3)return null;
    if(subarray2.length<3)return null;
        
    var month = Number(subarray1[0]);
    var day = Number(subarray1[1]);
    var year = Number(subarray1[2]);
    var hour = Number(subarray2[0]);
    var minute  = Number(subarray2[1]);
    var second = Number(subarray2[2]);
    
    var date = new Date();
    date.setFullYear(year,month-1,day);
    date.setHours(hour);
    date.setMinutes(minute);
    date.setSeconds(second);    
    return date;
},

/**
* parse the server date object and get the local date object
**/
getLocalDate:function(date)
{
    var EDT = this.isEDT(date);
    var localDate = new Date();
    var localOffset = localDate.getTimezoneOffset();
    var serverOffset = 300;
    if(EDT)serverOffset = 240;
    var totalOffset = localOffset - serverOffset;
    
    localDate.setTime(date.getTime()-totalOffset*60*1000);
    return localDate;
},

/**
* whether two date objects are in the same day.
* precondition: two date objects are just different in timezone, so
* we can just decide the day
**/
sameDay:function(date1, date2)
{
    var day1 = date1.getDate();
    var day2 = date2.getDate();
    if(day1 == day2)return true;
    else return false;
},

isEDT:function(date)
{       
    var dayOfWeek = date.getDay();
    var month = date.getMonth()+1;
    var day = date.getDate();
    
    if(month == 1 || month ==2 || month == 12)return false;
    else if(month == 4 || month ==5 || month == 6|| month == 7 || month == 8 || month == 9 || month == 10)return true;
    else if(month == 3)
    {
        if(this.exceedSecondSunday(day,date))return true;
        else return false;
     }
    else if(month == 11)
    {
        if(this.exceedFirstSunday(day,date))return false;
        else return true;
    }
    return true;    
},

exceedSecondSunday:function(day, date)
{
    var tempDate = new Date();
    tempDate.setFullYear(date.getFullYear());
    tempDate.setMonth(date.getMonth());
    tempDate.setDate(1);    
    var tempDayOfWeek = tempDate.getDay();
    var secondSunday;
    
    if(tempDayOfWeek == 0)secondSunday = 8;
    else if(tempDayOfWeek == 1)secondSunday = 14;
    else if(tempDayOfWeek == 2)secondSunday = 13;
    else if(tempDayOfWeek == 3)secondSunday = 12;
    else if(tempDayOfWeek == 4)secondSunday = 11;
    else if(tempDayOfWeek == 5)secondSunday = 10;
    else if(tempDayOfWeek == 6)secondSunday = 9;
    if(day >= secondSunday)return true;
    else return false;    
},

exceedFirstSunday:function(day, date)
{  
    var tempDate = new Date();
    tempDate.setFullYear(date.getFullYear());
    tempDate.setMonth(date.getMonth());
    tempDate.setDate(1);
    var tempDayOfWeek = tempDate.getDay();
    var firstSunday;
    
    if(tempDayOfWeek == 0)firstSunday = 1;
    else if(tempDayOfWeek == 1)firstSunday = 7;
    else if(tempDayOfWeek == 2)firstSunday = 6;
    else if(tempDayOfWeek == 3)firstSunday = 5;
    else if(tempDayOfWeek == 4)firstSunday = 4;
    else if(tempDayOfWeek == 5)firstSunday = 3;
    else if(tempDayOfWeek == 6)firstSunday = 2;
    if(day >= firstSunday)return true;
    else return false;    
},
convertMonthDisplay:function(month){
	   	var monthDisplay ="";
					if(month==01){
						monthDisplay ="Jan";
					}else if(month==02){
						monthDisplay ="Feb";
					}else if(month==03){
						monthDisplay ="Mar";
					}else if(month==04){
						monthDisplay ="Apr";
					}else if(month==05){
						monthDisplay ="May";
					}else if(month==06){
						monthDisplay ="Jun";
					}else if(month==07){
						monthDisplay ="Jul";
					}else if(month==08){
						monthDisplay ="Aug";
					}else if(month==09){
						monthDisplay ="Sep";
					}else if(month==10){
						monthDisplay ="Oct";
					}else if(month==11){
						monthDisplay ="Nov";
					}else if(month==12){
						monthDisplay ="Dec";
					}
	     return monthDisplay;		
},
getFullDateStr:function(date){
	var yyyyMMddStr="";
	var parseDate = date;
	var year = parseDate.getFullYear();
	var month = parseDate.getMonth()+1;
	if(month<=9)month="0"+month;
	var dd = parseDate.getDate();
	if(dd<=9)dd="0"+dd;
	yyyyMMddStr=""+year+month+dd;
	return yyyyMMddStr;	   
},
getMonthStrFromDate:function(date){
	var parseDate = date;
	var month = parseDate.getMonth() + 1;
	if(month<=9)month="0"+month;	
	return month;	
},
getDayStrFromDate:function(date){
	var parseDate = date;
	var day = parseDate.getDate();
	if(day<=9)day="0"+day;	
	return day;
},
getTimePassed:function(date) {
		var time = date;
		var currDate = new Date();
		var now = currDate.getTime();		
		var ellapse = now - time;
		var minutes = ellapse / 1000 / 60;
		var mins = Math.floor(minutes % 60);
		var hours = Math.floor(minutes / 60);
		var days = Math.floor(minutes / 60 /24);
		var str = "";
		if(days > 0) {
			minutes -= days*60*24;
			mins = Math.floor(minutes % 60);
			hours = Math.floor(minutes / 60);
			if (days == 1) {
				str +="1 day ";
			} else {
				str += days+" days ";
			}
		}
		if (hours > 0) {
			if (hours == 1) {
				str +="1 hour ";
			} else {
				str += hours+" hours ";
			}
		}
		if (mins <= 1) {
			str+=mins+" min ago";
		} else {
			str+=mins+" mins ago";
		}
		return str;
}
};